<template>
    <div class="app-container">
        <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
            <el-form-item label="模板标题" prop="tempTitle">
                <el-input v-model="queryParams.tempTitle" placeholder="请输入模板标题" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="模板类型" prop="tempType">
                <el-select v-model="queryParams.tempType" placeholder="请选择模板类型" clearable>
                    <el-option v-for="dict in dict.type.tj_send_type" :key="dict.value" :label="dict.label"
                        :value="dict.value" />
                </el-select>
            </el-form-item>
            <el-form-item>
                <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
                <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button type="primary" icon="el-icon-plus" size="mini" @click="handleAdd"
                    v-hasPermi="['hosp:sendTemplate:add']">新增
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="primary" icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
                    v-hasPermi="['hosp:sendTemplate:edit']">修改
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="primary" icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
                    v-hasPermi="['hosp:sendTemplate:remove']">删除
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="primary" icon="el-icon-download" size="mini" @click="handleExport"
                    v-hasPermi="['hosp:sendTemplate:export']">导出
                </el-button>
            </el-col>
            <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
        </el-row>

        <el-table v-loading="loading" :data="sendTemplateList" @selection-change="handleSelectionChange" border>
            <el-table-column type="selection" width="45" align="center" />
            <el-table-column label="编号" align="center" prop="id" width="60" />
            <el-table-column label="模板标题" align="center" prop="tempTitle" width="100" />
            <el-table-column label="模板内容" align="center" prop="tempContent" />
            <el-table-column label="模板类型" align="center" prop="tempType" width="100">
                <template slot-scope="scope">
                    <dict-tag :options="dict.type.tj_send_type" :value="scope.row.tempType" />
                </template>
            </el-table-column>
            <el-table-column label="停用标志" align="center" prop="flag" width="100">
                <template slot-scope="scope">
                    <dict-tag :options="dict.type.sys_normal_disable" :value="scope.row.flag" />
                </template>
            </el-table-column>
            <el-table-column label="操作" align="center" class-name="small-padding fixed-width" width="120">
                <template slot-scope="scope">
                    <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
                        v-hasPermi="['hosp:sendTemplate:edit']" title="修改">
                    </el-button>
                    <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
                        v-hasPermi="['hosp:sendTemplate:remove']" title="删除">
                    </el-button>
                </template>
            </el-table-column>
        </el-table>
        <div class="pag">
            <div class="pag1">
                <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
            @pagination="getList" />
            </div>
        </div>
       

        <!-- 添加或修改邮件短信模板对话框 -->
        <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
            <el-form ref="form" :model="form" :rules="rules" label-width="80px">
                <el-form-item label="模板标题" prop="tempTitle">
                    <el-input v-model="form.tempTitle" placeholder="请输入模板标题" />
                </el-form-item>
                <el-form-item label="模板内容">
                    <el-input type="textarea" v-model="form.tempContent"   :rows="3"></el-input>
                    <!-- <editor v-model="form.tempContent" :min-height="192" /> -->
                </el-form-item>
                <el-form-item label="模板类型" prop="tempType">
                    <el-select v-model="form.tempType" placeholder="请选择模板类型">
                        <el-option v-for="dict in dict.type.tj_send_type" :key="dict.value" :label="dict.label"
                            :value="dict.value"></el-option>
                    </el-select>
                </el-form-item>
                <el-form-item label="停用标志" prop="flag">
                    <el-select v-model="form.flag" placeholder="请选择停用标志">
                        <el-option v-for="dict in dict.type.sys_normal_disable" :key="dict.value" :label="dict.label"
                            :value="dict.value"></el-option>
                    </el-select>
                </el-form-item>
            </el-form>
            <div slot="footer" class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import {
    listSendTemplate,
    getSendTemplate,
    delSendTemplate,
    addSendTemplate,
    updateSendTemplate
} from "@/api/hosp/sendTemplate";

export default {
    name: "SendTemplate",
    dicts: ['tj_send_type', 'sys_normal_disable'],
    data() {
        return {
            // 遮罩层
            loading: true,
            // 选中数组
            ids: [],
            // 非单个禁用
            single: true,
            // 非多个禁用
            multiple: true,
            // 显示搜索条件
            showSearch: true,
            // 总条数
            total: 0,
            // 邮件短信模板表格数据
            sendTemplateList: [],
            // 弹出层标题
            title: "",
            // 是否显示弹出层
            open: false,
            // 查询参数
            queryParams: {
                pageNum: 1,
                pageSize: 10,
                tempTitle: null,
                tempContent: null,
                tempType: null,
            },
            // 表单参数
            form: {},
            // 表单校验
            rules: {
                tempTitle: [
                    {
                        required: true, message: "模板标题不能为空", trigger: "blur"
                    }
                ],
                tempContent: [
                    {
                        required: true, message: "模板内容不能为空", trigger: "blur"
                    }
                ],
                tempType: [
                    {
                        required: true, message: "模板类型不能为空", trigger: "change"
                    }
                ],
            }
        };
    },
    created() {
        this.getList();
    },
    methods: {
        /** 查询邮件短信模板列表 */
        getList() {
            this.loading = true;
            listSendTemplate(this.queryParams).then(response => {
                this.sendTemplateList = response.rows;
                this.total = response.total;
                this.loading = false;
            });
        },
        // 取消按钮
        cancel() {
            this.open = false;
            this.reset();
        },
        // 表单重置
        reset() {
            this.form = {
                id: null,
                tempTitle: null,
                tempContent: null,
                tempType: null,
                deleted: null,
                createBy: null,
                createTime: null,
                updateBy: null,
                updateTime: null,
                flag: null
            };
            this.resetForm("form");
        },
        /** 搜索按钮操作 */
        handleQuery() {
            this.queryParams.pageNum = 1;
            this.getList();
        },
        /** 重置按钮操作 */
        resetQuery() {
            this.resetForm("queryForm");
            this.handleQuery();
        },
        // 多选框选中数据
        handleSelectionChange(selection) {
            this.ids = selection.map(item => item.id)
            this.single = selection.length !== 1
            this.multiple = !selection.length
        },
        /** 新增按钮操作 */
        handleAdd() {
            this.reset();
            this.open = true;
            this.title = "添加邮件短信模板";
        },
        /** 修改按钮操作 */
        handleUpdate(row) {
            this.reset();
            const id = row.id || this.ids
            getSendTemplate(id).then(response => {
                this.form = response.data;
                this.open = true;
                this.title = "修改邮件短信模板";
            });
        },

        // 删除模板
        handleDelete(row) {
            const ids = row.id || this.ids;
            this.$modal.confirm('是否确认删除体检流水编号为"' + ids + '"的数据项？').then(function () {
                return delSendTemplate(ids);
            }).then(() => {
                this.getList();
                this.$modal.msgSuccess("删除成功");
            }).catch(() => { });
        },

        // 导出模板
        handleExport() {
            this.download(
                "hosp/sendTemplate/export",
                {
                    ...this.queryParams,
                },
                `order_${new Date().getTime()}.xlsx`
            );
        },
        // 模板新增或修改
        submitForm() {
            this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateSendTemplate(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addSendTemplate(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
        },
    }
}
    ;
</script>

<style>
.pag {
  width: 100%;
  display: flex;
  justify-content: center;
}
.pag1 {
  width: 30%;
}
</style>
